@@ -1,6 +1,6 @@
 use darling::{
     ast::{Data, Fields},
-    util::Ignored,
+    util::{Ignored, SpannedValue},
     FromDeriveInput, FromField, FromVariant,
 };
 use proc_macro2::{Ident, Span, TokenStream};
@@ -8,6 +8,7 @@ use quote::quote;
 use syn::{Attribute, DeriveInput, Error, Generics, Path, Type};
 
 use crate::{
+    common_args::ExternalDocument,
     error::GeneratorResult,
     utils::{get_crate_name, get_description, optional_literal},
 };
@@ -20,6 +21,8 @@ struct ResponseField {
 
     #[darling(default)]
     header: Option<String>,
+    #[darling(default)]
+    external_docs: Option<SpannedValue<ExternalDocument>>,
 }
 
 #[derive(FromVariant)]
@@ -70,7 +73,7 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
         let item_ident = &variant.ident;
         let item_description = get_description(&variant.attrs)?;
         let item_description = optional_literal(&item_description);
-        let (values, headers) = parse_fields(&variant.fields);
+        let (values, headers) = parse_fields(&variant.fields)?;
 
         let mut match_headers = Vec::new();
         let mut with_headers = Vec::new();
@@ -82,6 +85,13 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
             let header_name = header.header.as_ref().unwrap().to_uppercase();
             let header_ty = &header.ty;
             let header_desc = optional_literal(&get_description(&header.attrs)?);
+            let external_docs = match &header.external_docs {
+                Some(external_docs) => {
+                    let s = external_docs.to_token_stream(&crate_name);
+                    quote!(::std::option::Option::Some(#s))
+                }
+                None => quote!(::std::option::Option::None),
+            };
 
             with_headers.push(quote! {{
                 if let Some(header) = #crate_name::types::ToHeader::to_header(&#ident) {
@@ -93,6 +103,7 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
                 #crate_name::registry::MetaHeader {
                     name: #header_name,
                     description: #header_desc,
+                    external_docs: #external_docs,
                     required: <#header_ty as #crate_name::types::Type>::IS_REQUIRED,
                     schema: <#header_ty as #crate_name::types::Type>::schema_ref(),
                 }
@@ -279,7 +290,9 @@ fn get_status(span: Span, status: Option<u16>) -> GeneratorResult<TokenStream> {
     Ok(quote!(#status))
 }
 
-fn parse_fields(fields: &Fields<ResponseField>) -> (Vec<&ResponseField>, Vec<&ResponseField>) {
+fn parse_fields(
+    fields: &Fields<ResponseField>,
+) -> syn::Result<(Vec<&ResponseField>, Vec<&ResponseField>)> {
     let mut values = Vec::new();
     let mut headers = Vec::new();
 
@@ -287,9 +300,15 @@ fn parse_fields(fields: &Fields<ResponseField>) -> (Vec<&ResponseField>, Vec<&Re
         if field.header.is_some() {
             headers.push(field);
         } else {
+            if let Some(external_docs) = &field.external_docs {
+                return Err(syn::Error::new(
+                    external_docs.span(),
+                    "Only HTTP header field can define external documents.",
+                ));
+            }
             values.push(field);
         }
     }
 
-    (values, headers)
+    Ok((values, headers))
 }
